Author: hbelusca
Date: Thu Apr 4 20:26:36 2013
New Revision: 58682
URL: http://svn.reactos.org/svn/reactos?rev=58682&view=rev
Log:
[REACTOS]
"isnt" --> "isn't" and "arent" --> "aren't"
Modified:
trunk/reactos/base/shell/cmd/copy.c
trunk/reactos/base/shell/cmd/del.c
trunk/reactos/base/shell/cmd/readme2.txt
trunk/reactos/base/shell/cmd/ren.c
trunk/reactos/base/shell/cmd/ren.txt
trunk/reactos/base/shell/cmd/todo.txt
trunk/reactos/drivers/ksfilter/ks/api.c
Modified: trunk/reactos/base/shell/cmd/copy.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/shell/cmd/copy.c?rev=…
==============================================================================
--- trunk/reactos/base/shell/cmd/copy.c [iso-8859-1] (original)
+++ trunk/reactos/base/shell/cmd/copy.c [iso-8859-1] Thu Apr 4 20:26:36 2013
@@ -785,7 +785,7 @@
_tcscpy(tmpDestPath, szDestPath);
_tcscat(tmpDestPath, _T("\\"));
- /* Can't put a file into a folder that isnt there */
+ /* Can't put a file into a folder that isn't there */
if (_tcscmp(tmpDestPath, _T("\\\\.\\")) &&
!IsExistingDirectory(tmpDestPath))
{
Modified: trunk/reactos/base/shell/cmd/del.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/shell/cmd/del.c?rev=5…
==============================================================================
--- trunk/reactos/base/shell/cmd/readme2.txt [iso-8859-1] (original)
+++ trunk/reactos/base/shell/cmd/readme2.txt [iso-8859-1] Thu Apr 4 20:26:36 2013
@@ -4,7 +4,7 @@
This can cause a problem on older machines and that is why we have our own custom _CommandLineToArgvW to help this along.
We pull in the launch directory as the initial dir and set that in _tchdir. We make a handle to the default console out using CreateFile.
-Then we call Initialize(). Here we need to load ntdll.dll if it isnt loaded(windows 9x machines).
+Then we call Initialize(). Here we need to load ntdll.dll if it isn't loaded (windows 9x machines).
We also setup some global vars like default io handles and nErrorLevel and set %prompt% to $P$G.
This is where all command lines switches given to cmd on startup are done.
@@ -32,7 +32,7 @@
Some useful functions that are used a lot:
-split() - splits a string into an array of string on spaces that arent inside quotes. which you need to call freep() on later t clean up.
+split() - splits a string into an array of string on spaces that aren't inside quotes. which you need to call freep() on later t clean up.
//Split it´s used to take the Arguments from Command Line,it´s the best option for almost all the cases.
//If the Command has special needs as Dir, it´s better to make a Parser INSIDE that Command(as DIR has)
//Dont get mad(as i did): Split() can be find in Misc.c file.Really easy to follow.
Modified: trunk/reactos/base/shell/cmd/ren.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/shell/cmd/ren.c?rev=5…
==============================================================================
--- trunk/reactos/base/shell/cmd/ren.c [iso-8859-1] (original)
+++ trunk/reactos/base/shell/cmd/ren.c [iso-8859-1] Thu Apr 4 20:26:36 2013
@@ -223,7 +223,7 @@
}
- if (!_tcschr(srcPattern, _T('\\'))) //If srcPattern isnt a Path but a name:
+ if (!_tcschr(srcPattern, _T('\\'))) //If srcPattern isn't a Path but a name:
{
srcFILE=srcPattern;
if(_tcschr(dstPattern, _T('\\')))
Modified: trunk/reactos/base/shell/cmd/ren.txt
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/shell/cmd/ren.txt?rev…
==============================================================================
--- trunk/reactos/base/shell/cmd/ren.txt [iso-8859-1] (original)
+++ trunk/reactos/base/shell/cmd/ren.txt [iso-8859-1] Thu Apr 4 20:26:36 2013
@@ -28,7 +28,7 @@
3)Syntax errors:
-Way #1 with different Subdirectories path: ren c:\ie\hello.txt c:\hi\hi.txt, this is not possible.Since ren doesnt move files,just rename them.
--Way #2 semi path in destiny: ren hello.txt c:\ie\hi.txt. This feature isnt available.
+-Way #2 semi path in destiny: ren hello.txt c:\ie\hi.txt. This feature isn't available.
**************************************************
Modified: trunk/reactos/base/shell/cmd/todo.txt
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/shell/cmd/todo.txt?re…
==============================================================================
--- trunk/reactos/base/shell/cmd/todo.txt [iso-8859-1] (original)
+++ trunk/reactos/base/shell/cmd/todo.txt [iso-8859-1] Thu Apr 4 20:26:36 2013
@@ -7,7 +7,7 @@
Not sure what is wrong with it, put probably more then just one thing blocking this. For sure pipes break when it is compiled as unicode.
*Move.c code clean up
-It works, but it needs to be cleaned up, the code is long and overly complex for what it needs to do. Also, we can remove the hack to cover for MoveFileEx bug as it isnt a bug anymore.
+It works, but it needs to be cleaned up, the code is long and overly complex for what it needs to do. Also, we can remove the hack to cover for MoveFileEx bug as it isn't a bug anymore.
*If rewrite
It works decent but looks _awful_. Very hard to maintain and/or understand what the hell is going on.
Modified: trunk/reactos/drivers/ksfilter/ks/api.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/ksfilter/ks/api.c?…
==============================================================================
--- trunk/reactos/drivers/ksfilter/ks/api.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/ksfilter/ks/api.c [iso-8859-1] Thu Apr 4 20:26:36 2013
@@ -2060,7 +2060,7 @@
/* set counter */
Count = AutomationTableA->MethodSetsCount;
- /* now copy entries which arent available in the dominant table */
+ /* now copy entries which aren't available in the dominant table */
for(Index = 0; Index < AutomationTableB->MethodSetsCount; Index++)
{
/* set found to false */
@@ -2200,7 +2200,7 @@
/* set counter */
Count = AutomationTableA->PropertySetsCount;
- /* now copy entries which arent available in the dominant table */
+ /* now copy entries which aren't available in the dominant table */
for(Index = 0; Index < AutomationTableB->PropertySetsCount; Index++)
{
/* set found to false */
@@ -2265,7 +2265,7 @@
/* set counter */
Count = AutomationTableA->EventSetsCount;
- /* now copy entries which arent available in the dominant table */
+ /* now copy entries which aren't available in the dominant table */
for(Index = 0; Index < AutomationTableB->EventSetsCount; Index++)
{
/* set found to false */
Author: hbelusca
Date: Thu Apr 4 20:15:34 2013
New Revision: 58681
URL: http://svn.reactos.org/svn/reactos?rev=58681&view=rev
Log:
[REACTOS]
Fix a remaining "initialize" misspelling here, too.
Modified:
trunk/reactos/dll/win32/kernel32/winnls/lang/de-DE.mc
Modified: trunk/reactos/dll/win32/kernel32/winnls/lang/de-DE.mc
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/kernel32/winnls/…
==============================================================================
--- trunk/reactos/dll/win32/kernel32/winnls/lang/de-DE.mc [iso-8859-1] (original)
+++ trunk/reactos/dll/win32/kernel32/winnls/lang/de-DE.mc [iso-8859-1] Thu Apr 4 20:15:34 2013
@@ -1917,7 +1917,7 @@
Facility=System
SymbolicName=ERROR_APP_INIT_FAILURE
Language=German
-ERROR_APP_INIT_FAILURE - Das Programm konnte nicht richtig initalisiert werden (0x%lx). Klicken Sie auf OK, um das Programm zu beenden.
+ERROR_APP_INIT_FAILURE - Das Programm konnte nicht richtig initialisiert werden (0x%lx). Klicken Sie auf OK, um das Programm zu beenden.
.
MessageId=576
Author: hbelusca
Date: Thu Apr 4 20:11:17 2013
New Revision: 58679
URL: http://svn.reactos.org/svn/reactos?rev=58679&view=rev
Log:
[REACTOS]
Fix TOO MANY !! :(((( "initialize" misspellings.
Note1: One remains in subsystems/csr/csrsrv/init.c, but will be corrected in my future csrss branch merging.
Note2: In ntoskrnl/se/semgr.c, one tries to create the "LSA_AUTHENTICATION_INITALIZED" event. This is ROS-SPECIFIC !!!! In the sense that it doesn't exist on Windows. Instead, the "LSA_AUTHENTICATION_INITIALIZED" exists. Correct that fact.
Modified:
trunk/reactos/base/shell/cmd/readme2.txt
trunk/reactos/boot/freeldr/freeldr/arch/amd64/winldr.c
trunk/reactos/boot/freeldr/freeldr/arch/i386/winldr.c
trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c
trunk/reactos/dll/win32/shell32/dde.cpp
trunk/reactos/drivers/filesystems/cdfs/cdfs.c
trunk/reactos/drivers/filesystems/mup/mup.c
trunk/reactos/drivers/filesystems/ntfs/ntfs.c
trunk/reactos/drivers/multimedia/audio/mpu401_nt4/mpu401.c
trunk/reactos/drivers/multimedia/audio/sndblst.old/sndblst.c
trunk/reactos/drivers/multimedia/audio/sound/sb16.c
trunk/reactos/drivers/multimedia/audio/sound/sound.c
trunk/reactos/drivers/network/tcpip/datalink/lan.c
trunk/reactos/drivers/parallel/parallel/parallel.c
trunk/reactos/drivers/storage/class/class2/class2.c
trunk/reactos/drivers/storage/classpnp/obsolete.c
trunk/reactos/drivers/storage/classpnp/power.c
trunk/reactos/hal/halppc/generic/display.c
trunk/reactos/hal/halppc/generic/dma.c
trunk/reactos/hal/halppc/up/halinit_up.c
trunk/reactos/hal/halx86/apic/apic.c
trunk/reactos/hal/halx86/apic/halinit_apic.c
trunk/reactos/hal/halx86/generic/dma.c
trunk/reactos/hal/halx86/mp/halinit_mp.c
trunk/reactos/hal/halx86/up/halinit_mini.c
trunk/reactos/hal/halx86/up/halinit_up.c
trunk/reactos/hal/halx86/xbox/halinit_xbox.c
trunk/reactos/lib/cmlib/hiveinit.c
trunk/reactos/lib/smlib/smclient.c
trunk/reactos/ntoskrnl/ex/event.c
trunk/reactos/ntoskrnl/ex/evtpair.c
trunk/reactos/ntoskrnl/ex/mutant.c
trunk/reactos/ntoskrnl/ex/zone.c
trunk/reactos/ntoskrnl/io/iomgr/driver.c
trunk/reactos/ntoskrnl/io/iomgr/util.c
trunk/reactos/ntoskrnl/ke/amd64/krnlinit.c
trunk/reactos/ntoskrnl/ke/i386/usercall_asm.S
trunk/reactos/ntoskrnl/ke/thrdobj.c
trunk/reactos/ntoskrnl/ke/timerobj.c
trunk/reactos/ntoskrnl/se/semgr.c
trunk/reactos/win32ss/drivers/font/ftfd/font.c
trunk/reactos/win32ss/user/ntuser/winsta.c
Modified: trunk/reactos/base/shell/cmd/readme2.txt
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/shell/cmd/readme2.txt…
==============================================================================
--- trunk/reactos/base/shell/cmd/readme2.txt [iso-8859-1] (original)
+++ trunk/reactos/base/shell/cmd/readme2.txt [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -1,8 +1,8 @@
-General Overview of How THings Work
+General Overview of How Things Work
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
First it comes into _main in cmd.c(1811). The command line params are taking in and if it is unicode it uses CommandLineToArgvW.
This can cause a problem on older machines and that is why we have our own custom _CommandLineToArgvW to help this along.
-We pull in the launch directory as the inital dir and set that in _tchdir. We make a handle to the default console out using CreateFile.
+We pull in the launch directory as the initial dir and set that in _tchdir. We make a handle to the default console out using CreateFile.
Then we call Initialize(). Here we need to load ntdll.dll if it isnt loaded(windows 9x machines).
We also setup some global vars like default io handles and nErrorLevel and set %prompt% to $P$G.
Modified: trunk/reactos/boot/freeldr/freeldr/arch/amd64/winldr.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/…
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/amd64/winldr.c [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/amd64/winldr.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -343,7 +343,7 @@
/* Disable Interrupts */
_disable();
- /* Re-initalize EFLAGS */
+ /* Re-initialize EFLAGS */
__writeeflags(0);
/* Set the new PML4 */
Modified: trunk/reactos/boot/freeldr/freeldr/arch/i386/winldr.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/…
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/i386/winldr.c [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/i386/winldr.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -429,7 +429,7 @@
// Disable Interrupts
_disable();
- // Re-initalize EFLAGS
+ // Re-initialize EFLAGS
__writeeflags(0);
// Set the PDBR
Modified: trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/…
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -672,7 +672,7 @@
* FrLdrMapKernel
* INTERNAL
*
- * Maps the Kernel into memory, does PE Section Mapping, initalizes the
+ * Maps the Kernel into memory, does PE Section Mapping, initializes the
* uninitialized data sections, and relocates the image.
*
* Params:
Modified: trunk/reactos/dll/win32/shell32/dde.cpp
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/dll/win32/shell32/dde.cpp?…
==============================================================================
--- trunk/reactos/dll/win32/shell32/dde.cpp [iso-8859-1] (original)
+++ trunk/reactos/dll/win32/shell32/dde.cpp [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -122,7 +122,7 @@
* can use them.
*
* PARAMS
- * bInit [I] TRUE to initialize the services, FALSE to uninitalize.
+ * bInit [I] TRUE to initialize the services, FALSE to uninitialize.
*
* RETURNS
* Nothing.
Modified: trunk/reactos/drivers/filesystems/cdfs/cdfs.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/filesystems/cdfs/c…
==============================================================================
--- trunk/reactos/drivers/filesystems/cdfs/cdfs.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/filesystems/cdfs/cdfs.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -43,7 +43,7 @@
DriverEntry(PDRIVER_OBJECT DriverObject,
PUNICODE_STRING RegistryPath)
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/filesystems/mup/mup.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/filesystems/mup/mu…
==============================================================================
--- trunk/reactos/drivers/filesystems/mup/mup.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/filesystems/mup/mup.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -37,7 +37,7 @@
/* FUNCTIONS ****************************************************************/
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/filesystems/ntfs/ntfs.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/filesystems/ntfs/n…
==============================================================================
--- trunk/reactos/drivers/filesystems/ntfs/ntfs.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/filesystems/ntfs/ntfs.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -42,7 +42,7 @@
DriverEntry(PDRIVER_OBJECT DriverObject,
PUNICODE_STRING RegistryPath)
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/multimedia/audio/mpu401_nt4/mpu401.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/multimedia/audio/m…
==============================================================================
--- trunk/reactos/drivers/multimedia/audio/mpu401_nt4/mpu401.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/multimedia/audio/mpu401_nt4/mpu401.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -361,7 +361,7 @@
DriverEntry(PDRIVER_OBJECT DriverObject,
PUNICODE_STRING RegistryPath)
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/multimedia/audio/sndblst.old/sndblst.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/multimedia/audio/s…
==============================================================================
--- trunk/reactos/drivers/multimedia/audio/sndblst.old/sndblst.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/multimedia/audio/sndblst.old/sndblst.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -420,7 +420,7 @@
DriverEntry(PDRIVER_OBJECT DriverObject,
PUNICODE_STRING RegistryPath)
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/multimedia/audio/sound/sb16.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/multimedia/audio/s…
==============================================================================
--- trunk/reactos/drivers/multimedia/audio/sound/sb16.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/multimedia/audio/sound/sb16.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -24,7 +24,7 @@
DriverEntry(PDRIVER_OBJECT DriverObject,
PUNICODE_STRING RegistryPath)
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/multimedia/audio/sound/sound.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/multimedia/audio/s…
==============================================================================
--- trunk/reactos/drivers/multimedia/audio/sound/sound.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/multimedia/audio/sound/sound.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -71,7 +71,7 @@
NTSTATUS ModuleEntry(PDRIVER_OBJECT DriverObject, PUNICODE_STRING RegistryPath)
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/network/tcpip/datalink/lan.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/network/tcpip/data…
==============================================================================
--- trunk/reactos/drivers/network/tcpip/datalink/lan.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/network/tcpip/datalink/lan.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -705,7 +705,7 @@
//NDIS_STATUS NdisStatus;
IP_ADDRESS DefaultMask;
- /* Initalize the default unspecified address (0.0.0.0) */
+ /* Initialize the default unspecified address (0.0.0.0) */
AddrInitIPv4(&DefaultMask, 0);
if (Context->State == LAN_STATE_STARTED &&
!Context->Adapter->CompletingReset)
Modified: trunk/reactos/drivers/parallel/parallel/parallel.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/parallel/parallel/…
==============================================================================
--- trunk/reactos/drivers/parallel/parallel/parallel.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/parallel/parallel/parallel.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -122,7 +122,7 @@
NTSTATUS NTAPI
DriverEntry(PDRIVER_OBJECT DriverObject, PUNICODE_STRING RegistryPath)
/*
- * FUNCTION: Called by the system to initalize the driver
+ * FUNCTION: Called by the system to initialize the driver
* ARGUMENTS:
* DriverObject = object describing this driver
* RegistryPath = path to our configuration entries
Modified: trunk/reactos/drivers/storage/class/class2/class2.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/storage/class/clas…
==============================================================================
--- trunk/reactos/drivers/storage/class/class2/class2.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/storage/class/class2/class2.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -3104,7 +3104,7 @@
Routine Description:
- This routine reinitalizes the necessary fields, and sends the request
+ This routine reinitializes the necessary fields, and sends the request
to the port driver.
Arguments:
Modified: trunk/reactos/drivers/storage/classpnp/obsolete.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/storage/classpnp/o…
==============================================================================
--- trunk/reactos/drivers/storage/classpnp/obsolete.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/storage/classpnp/obsolete.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -316,7 +316,7 @@
Routine Description:
This is a wrapper around the delayed retry DPC routine, RetryRequestDPC.
- This reinitalizes the necessary fields, queues the request, and sets
+ This reinitializes the necessary fields, queues the request, and sets
a timer to call the DPC if someone hasn't already done so.
Arguments:
Modified: trunk/reactos/drivers/storage/classpnp/power.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/storage/classpnp/p…
==============================================================================
--- trunk/reactos/drivers/storage/classpnp/power.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/storage/classpnp/power.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -1494,7 +1494,7 @@
Routine Description:
- This routine reinitalizes the necessary fields, and sends the request
+ This routine reinitializes the necessary fields, and sends the request
to the lower driver.
Arguments:
Modified: trunk/reactos/hal/halppc/generic/display.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halppc/generic/display…
==============================================================================
--- trunk/reactos/hal/halppc/generic/display.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halppc/generic/display.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -221,7 +221,7 @@
VOID FASTCALL
HalInitializeDisplay (PROS_LOADER_PARAMETER_BLOCK LoaderBlock)
/*
- * FUNCTION: Initalize the display
+ * FUNCTION: Initialize the display
* ARGUMENTS:
* InitParameters = Parameters setup by the boot loader
*/
Modified: trunk/reactos/hal/halppc/generic/dma.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halppc/generic/dma.c?r…
==============================================================================
--- trunk/reactos/hal/halppc/generic/dma.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halppc/generic/dma.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -1688,7 +1688,7 @@
* transfer start.
* PhysicalAddress is physical address corresponding to the transfer
* start page and offset.
- * TransferLength is the inital length of the transfer, which is reminder
+ * TransferLength is the initial length of the transfer, which is reminder
* of the first page. The actual value is calculated below.
*
* Note that all the variables can change during the processing which
Modified: trunk/reactos/hal/halppc/up/halinit_up.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halppc/up/halinit_up.c…
==============================================================================
--- trunk/reactos/hal/halppc/up/halinit_up.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halppc/up/halinit_up.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -2,7 +2,7 @@
* COPYRIGHT: See COPYING in the top level directory
* PROJECT: ReactOS kernel
* FILE: ntoskrnl/hal/x86/halinit.c
- * PURPOSE: Initalize the x86 hal
+ * PURPOSE: Initialize the x86 hal
* PROGRAMMER: David Welch (welch(a)cwcom.net)
* UPDATE HISTORY:
* 11/06/98: Created
Modified: trunk/reactos/hal/halx86/apic/apic.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halx86/apic/apic.c?rev…
==============================================================================
--- trunk/reactos/hal/halx86/apic/apic.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halx86/apic/apic.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -365,7 +365,7 @@
LvtEntry.Mask = 1;
LvtEntry.TimerMode = 0;
- /* Initalize and mask LVTs */
+ /* Initialize and mask LVTs */
ApicWrite(APIC_TMRLVTR, LvtEntry.Long);
ApicWrite(APIC_THRMLVTR, LvtEntry.Long);
ApicWrite(APIC_PCLVTR, LvtEntry.Long);
Modified: trunk/reactos/hal/halx86/apic/halinit_apic.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halx86/apic/halinit_ap…
==============================================================================
--- trunk/reactos/hal/halx86/apic/halinit_apic.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halx86/apic/halinit_apic.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -2,7 +2,7 @@
* COPYRIGHT: See COPYING in the top level directory
* PROJECT: ReactOS kernel
* FILE: ntoskrnl/hal/x86/halinit.c
- * PURPOSE: Initalize the x86 hal
+ * PURPOSE: Initialize the x86 hal
* PROGRAMMER: Timo Kreuzer (timo.kreuzer(a)reactos.org)
*/
Modified: trunk/reactos/hal/halx86/generic/dma.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halx86/generic/dma.c?r…
==============================================================================
--- trunk/reactos/hal/halx86/generic/dma.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halx86/generic/dma.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -1850,7 +1850,7 @@
* transfer start.
* PhysicalAddress is physical address corresponding to the transfer
* start page and offset.
- * TransferLength is the inital length of the transfer, which is reminder
+ * TransferLength is the initial length of the transfer, which is reminder
* of the first page. The actual value is calculated below.
*
* Note that all the variables can change during the processing which
Modified: trunk/reactos/hal/halx86/mp/halinit_mp.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halx86/mp/halinit_mp.c…
==============================================================================
--- trunk/reactos/hal/halx86/mp/halinit_mp.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halx86/mp/halinit_mp.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -2,7 +2,7 @@
* COPYRIGHT: See COPYING in the top level directory
* PROJECT: ReactOS kernel
* FILE: hal/halx86/mp/halinit_mp.c
- * PURPOSE: Initalize the x86 mp hal
+ * PURPOSE: Initialize the x86 mp hal
* PROGRAMMER: David Welch (welch(a)cwcom.net)
* UPDATE HISTORY:
* 11/06/98: Created
Modified: trunk/reactos/hal/halx86/up/halinit_mini.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halx86/up/halinit_mini…
==============================================================================
--- trunk/reactos/hal/halx86/up/halinit_mini.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halx86/up/halinit_mini.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -2,7 +2,7 @@
* COPYRIGHT: See COPYING in the top level directory
* PROJECT: ReactOS kernel
* FILE: ntoskrnl/hal/x86/halinit.c
- * PURPOSE: Initalize the x86 hal
+ * PURPOSE: Initialize the x86 hal
* PROGRAMMER: David Welch (welch(a)cwcom.net)
* UPDATE HISTORY:
* 11/06/98: Created
Modified: trunk/reactos/hal/halx86/up/halinit_up.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halx86/up/halinit_up.c…
==============================================================================
--- trunk/reactos/hal/halx86/up/halinit_up.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halx86/up/halinit_up.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -2,7 +2,7 @@
* COPYRIGHT: See COPYING in the top level directory
* PROJECT: ReactOS kernel
* FILE: ntoskrnl/hal/x86/halinit.c
- * PURPOSE: Initalize the x86 hal
+ * PURPOSE: Initialize the x86 hal
* PROGRAMMER: David Welch (welch(a)cwcom.net)
* UPDATE HISTORY:
* 11/06/98: Created
Modified: trunk/reactos/hal/halx86/xbox/halinit_xbox.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/hal/halx86/xbox/halinit_xb…
==============================================================================
--- trunk/reactos/hal/halx86/xbox/halinit_xbox.c [iso-8859-1] (original)
+++ trunk/reactos/hal/halx86/xbox/halinit_xbox.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -2,7 +2,7 @@
* COPYRIGHT: See COPYING in the top level directory
* PROJECT: ReactOS kernel
* FILE: ntoskrnl/hal/x86/halinit.c
- * PURPOSE: Initalize the x86 hal
+ * PURPOSE: Initialize the x86 hal
* PROGRAMMER: David Welch (welch(a)cwcom.net)
* UPDATE HISTORY:
* 11/06/98: Created
Modified: trunk/reactos/lib/cmlib/hiveinit.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/lib/cmlib/hiveinit.c?rev=5…
==============================================================================
--- trunk/reactos/lib/cmlib/hiveinit.c [iso-8859-1] (original)
+++ trunk/reactos/lib/cmlib/hiveinit.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -83,7 +83,7 @@
/**
* @name HvpCreateHive
*
- * Internal helper function to initalize hive descriptor structure for
+ * Internal helper function to initialize hive descriptor structure for
* newly created hive.
*
* @see HvInitialize
@@ -126,7 +126,7 @@
/**
* @name HvpInitializeMemoryHive
*
- * Internal helper function to initalize hive descriptor structure for
+ * Internal helper function to initialize hive descriptor structure for
* a hive stored in memory. The data of the hive are copied and it is
* prepared for read/write access.
*
@@ -246,7 +246,7 @@
/**
* @name HvpInitializeMemoryInplaceHive
*
- * Internal helper function to initalize hive descriptor structure for
+ * Internal helper function to initialize hive descriptor structure for
* a hive stored in memory. The in-memory data of the hive are directly
* used and it is read-only accessible.
*
Modified: trunk/reactos/lib/smlib/smclient.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/lib/smlib/smclient.c?rev=5…
==============================================================================
--- trunk/reactos/lib/smlib/smclient.c [iso-8859-1] (original)
+++ trunk/reactos/lib/smlib/smclient.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -37,7 +37,7 @@
SmApiMsg.h.u1.s1.DataLength = sizeof(SM_EXEC_PGM_MSG) + 8;
SmApiMsg.h.u1.s1.TotalLength = sizeof(SmApiMsg);
- /* Initalize this specific API's parameters */
+ /* Initialize this specific API's parameters */
SmApiMsg.ApiNumber = SmExecPgmApi;
RtlCopyMemory(&SmApiMsg.u.ExecPgm.ProcessInformation,
ProcessInformation,
Modified: trunk/reactos/ntoskrnl/ex/event.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ex/event.c?rev=58…
==============================================================================
--- trunk/reactos/ntoskrnl/ex/event.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ex/event.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -142,7 +142,7 @@
/* Check for Success */
if (NT_SUCCESS(Status))
{
- /* Initalize the Event */
+ /* Initialize the Event */
KeInitializeEvent(Event,
EventType,
InitialState);
Modified: trunk/reactos/ntoskrnl/ex/evtpair.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ex/evtpair.c?rev=…
==============================================================================
--- trunk/reactos/ntoskrnl/ex/evtpair.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ex/evtpair.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -101,7 +101,7 @@
/* Check for Success */
if (NT_SUCCESS(Status))
{
- /* Initalize the Event */
+ /* Initialize the Event */
DPRINT("Initializing EventPair\n");
KeInitializeEventPair(EventPair);
Modified: trunk/reactos/ntoskrnl/ex/mutant.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ex/mutant.c?rev=5…
==============================================================================
--- trunk/reactos/ntoskrnl/ex/mutant.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ex/mutant.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -123,7 +123,7 @@
/* Check for success */
if(NT_SUCCESS(Status))
{
- /* Initalize the Kernel Mutant */
+ /* Initialize the Kernel Mutant */
DPRINT("Initializing the Mutant\n");
KeInitializeMutant(Mutant, InitialOwner);
Modified: trunk/reactos/ntoskrnl/ex/zone.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ex/zone.c?rev=586…
==============================================================================
--- trunk/reactos/ntoskrnl/ex/zone.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ex/zone.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -90,7 +90,7 @@
}
/*
- * FUNCTION: Initalizes a zone header
+ * FUNCTION: Initializes a zone header
* ARGUMENTS:
* Zone = zone header to be initialized
* BlockSize = Size (in bytes) of the allocation size of the zone
Modified: trunk/reactos/ntoskrnl/io/iomgr/driver.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/io/iomgr/driver.c…
==============================================================================
--- trunk/reactos/ntoskrnl/io/iomgr/driver.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/io/iomgr/driver.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -436,7 +436,7 @@
/*
* IopInitializeDriverModule
*
- * Initalize a loaded driver.
+ * Initialize a loaded driver.
*
* Parameters
* DeviceNode
Modified: trunk/reactos/ntoskrnl/io/iomgr/util.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/io/iomgr/util.c?r…
==============================================================================
--- trunk/reactos/ntoskrnl/io/iomgr/util.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/io/iomgr/util.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -171,17 +171,17 @@
PAGED_CODE();
- /* Length of the rest. Inital equal to EaLength */
+ /* Length of the rest */
IntEaLength = EaLength;
-
- /* Inital EaBuffer equal to EaBuffer */
EaBufferEnd = EaBuffer;
/* The rest length of the buffer */
while (IntEaLength >= FIELD_OFFSET(FILE_FULL_EA_INFORMATION, EaName[0]))
{
- /* rest of buffer must greater then the
- sizeof(FILE_FULL_EA_INFORMATION) + buffer */
+ /*
+ * The rest of buffer must greater than
+ * sizeof(FILE_FULL_EA_INFORMATION) + buffer
+ */
NextEaBufferOffset =
EaBufferEnd->EaNameLength + EaBufferEnd->EaValueLength +
FIELD_OFFSET(FILE_FULL_EA_INFORMATION, EaName[0]) + 1;
@@ -203,18 +203,21 @@
}
else
{
- /* From the MSDN
- http://msdn2.microsoft.com/en-us/library/ms795740.aspx
- For all entries except the last, the value of
- NextEntryOffset must be greater than zero and
- must fall on a ULONG boundary
+ /*
+ * From MSDN:
+ * http://msdn2.microsoft.com/en-us/library/ms795740.aspx
+ * For all entries except the last one, the value of
+ * NextEntryOffset must be greater than zero and
+ * must fall on a ULONG boundary.
*/
NextEaBufferOffset = ((NextEaBufferOffset + 3) & ~3);
if ((EaBufferEnd->NextEntryOffset == NextEaBufferOffset) &&
((LONG)EaBufferEnd->NextEntryOffset > 0))
{
- /* Rest of buffer must be greater then the
- next offset */
+ /*
+ * The rest of buffer must be greater
+ * than the following offset.
+ */
IntEaLength =
IntEaLength - EaBufferEnd->NextEntryOffset;
Modified: trunk/reactos/ntoskrnl/ke/amd64/krnlinit.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ke/amd64/krnlinit…
==============================================================================
--- trunk/reactos/ntoskrnl/ke/amd64/krnlinit.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ke/amd64/krnlinit.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -30,7 +30,7 @@
VOID
NTAPI
-KiInitalizeHandBuiltThread(
+KiInitializeHandBuiltThread(
IN PKTHREAD Thread,
IN PKPROCESS Process,
IN PVOID Stack)
@@ -92,7 +92,7 @@
else
{
/* Initialize the startup thread */
- KiInitalizeHandBuiltThread(Thread, Process, KernelStack);
+ KiInitializeHandBuiltThread(Thread, Process, KernelStack);
/* Initialize cpu with HAL */
if (!HalInitSystem(0, LoaderBlock))
@@ -212,7 +212,7 @@
InitProcess->QuantumReset = MAXCHAR;
/* Initialize the startup thread */
- KiInitalizeHandBuiltThread(InitThread, InitProcess, IdleStack);
+ KiInitializeHandBuiltThread(InitThread, InitProcess, IdleStack);
/* Initialize the Kernel Executive */
ExpInitializeExecutive(0, LoaderBlock);
Modified: trunk/reactos/ntoskrnl/ke/i386/usercall_asm.S
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ke/i386/usercall_…
==============================================================================
--- trunk/reactos/ntoskrnl/ke/i386/usercall_asm.S [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ke/i386/usercall_asm.S [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -59,7 +59,7 @@
/* load the address of the callout frame into ecx */
lea ecx, [esp - 12]
- /* Allocate space for the inital stack */
+ /* Allocate space for the initial stack */
sub esp, 12 + NPX_FRAME_LENGTH + KTRAP_FRAME_LENGTH + 16
call @KiUserModeCallout@4
Modified: trunk/reactos/ntoskrnl/ke/thrdobj.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ke/thrdobj.c?rev=…
==============================================================================
--- trunk/reactos/ntoskrnl/ke/thrdobj.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ke/thrdobj.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -772,7 +772,7 @@
PKTIMER Timer;
NTSTATUS Status;
- /* Initalize the Dispatcher Header */
+ /* Initialize the Dispatcher Header */
Thread->Header.Type = ThreadObject;
Thread->Header.ThreadControlFlags = 0;
Thread->Header.DebugActive = FALSE;
@@ -862,7 +862,7 @@
Status = STATUS_SUCCESS;
_SEH2_TRY
{
- /* Initalize the Thread Context */
+ /* Initialize the Thread Context */
KiInitializeContextThread(Thread,
SystemRoutine,
StartRoutine,
@@ -884,7 +884,7 @@
}
_SEH2_END;
- /* Set the Thread to initalized */
+ /* Set the Thread to initialized */
Thread->State = Initialized;
return Status;
}
Modified: trunk/reactos/ntoskrnl/ke/timerobj.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/ke/timerobj.c?rev…
==============================================================================
--- trunk/reactos/ntoskrnl/ke/timerobj.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/ke/timerobj.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -256,7 +256,7 @@
Timer->Header.SignalState = 0;
InitializeListHead(&(Timer->Header.WaitListHead));
- /* Initalize the Other data */
+ /* Initialize the Other data */
Timer->DueTime.QuadPart = 0;
Timer->Period = 0;
}
Modified: trunk/reactos/ntoskrnl/se/semgr.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/ntoskrnl/se/semgr.c?rev=58…
==============================================================================
--- trunk/reactos/ntoskrnl/se/semgr.c [iso-8859-1] (original)
+++ trunk/reactos/ntoskrnl/se/semgr.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -181,8 +181,7 @@
NTSTATUS Status;
/* Create '\Security' directory */
- RtlInitUnicodeString(&Name,
- L"\\Security");
+ RtlInitUnicodeString(&Name, L"\\Security");
InitializeObjectAttributes(&ObjectAttributes,
&Name,
OBJ_PERMANENT,
@@ -197,9 +196,8 @@
return FALSE;
}
- /* Create 'LSA_AUTHENTICATION_INITALIZED' event */
- RtlInitUnicodeString(&Name,
- L"\\LSA_AUTHENTICATION_INITALIZED");
+ /* Create 'LSA_AUTHENTICATION_INITIALIZED' event */
+ RtlInitUnicodeString(&Name, L"\\LSA_AUTHENTICATION_INITIALIZED");
InitializeObjectAttributes(&ObjectAttributes,
&Name,
OBJ_PERMANENT,
@@ -212,7 +210,7 @@
FALSE);
if (!NT_SUCCESS(Status))
{
- DPRINT1("Failed to create 'LSA_AUTHENTICATION_INITALIZED' event!\n");
+ DPRINT1("Failed to create 'LSA_AUTHENTICATION_INITIALIZED' event!\n");
NtClose(DirectoryHandle);
return FALSE;
}
Modified: trunk/reactos/win32ss/drivers/font/ftfd/font.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/win32ss/drivers/font/ftfd/…
==============================================================================
--- trunk/reactos/win32ss/drivers/font/ftfd/font.c [iso-8859-1] (original)
+++ trunk/reactos/win32ss/drivers/font/ftfd/font.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -382,7 +382,7 @@
return NULL;
}
- /* Get inital value for cGlyphs from ftface */
+ /* Get initial value for cGlyphs from ftface */
cGlyphs = ftface->num_glyphs + 1;
/* Allocate a buffer for the char codes and glyph indexes */
Modified: trunk/reactos/win32ss/user/ntuser/winsta.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/win32ss/user/ntuser/winsta…
==============================================================================
--- trunk/reactos/win32ss/user/ntuser/winsta.c [iso-8859-1] (original)
+++ trunk/reactos/win32ss/user/ntuser/winsta.c [iso-8859-1] Thu Apr 4 20:11:17 2013
@@ -23,7 +23,7 @@
/* Full path to WindowStations directory */
UNICODE_STRING gustrWindowStationsDir;
-/* INITALIZATION FUNCTIONS ****************************************************/
+/* INITIALIZATION FUNCTIONS ****************************************************/
INIT_FUNCTION
NTSTATUS
Author: hbelusca
Date: Thu Apr 4 19:47:42 2013
New Revision: 58678
URL: http://svn.reactos.org/svn/reactos?rev=58678&view=rev
Log:
[ROSTESTS]
Correct spelling and Co.
Modified:
trunk/rostests/drivers/csqtest/csqtest.c
trunk/rostests/drivers/ntoskrnl/IoEaTest.cpp
Modified: trunk/rostests/drivers/csqtest/csqtest.c
URL: http://svn.reactos.org/svn/reactos/trunk/rostests/drivers/csqtest/csqtest.c…
==============================================================================
--- trunk/rostests/drivers/csqtest/csqtest.c [iso-8859-1] (original)
+++ trunk/rostests/drivers/csqtest/csqtest.c [iso-8859-1] Thu Apr 4 19:47:42 2013
@@ -194,9 +194,9 @@
CsqAcquireLock, CsqReleaseLock, CsqCompleteCancelledIrp);
if(Status != STATUS_SUCCESS)
- KdPrint(("csqtest: IoCsqInitalize failed: 0x%x\n", Status));
+ KdPrint(("csqtest: IoCsqInitialize failed: 0x%x\n", Status));
else
- KdPrint(("csqtest: IoCsqInitalize succeeded\n"));
+ KdPrint(("csqtest: IoCsqInitialize succeeded\n"));
InitializeListHead(&IrpQueue);
KeInitializeSpinLock(&IrpQueueLock);
Modified: trunk/rostests/drivers/ntoskrnl/IoEaTest.cpp
URL: http://svn.reactos.org/svn/reactos/trunk/rostests/drivers/ntoskrnl/IoEaTest…
==============================================================================
--- trunk/rostests/drivers/ntoskrnl/IoEaTest.cpp [iso-8859-1] (original)
+++ trunk/rostests/drivers/ntoskrnl/IoEaTest.cpp [iso-8859-1] Thu Apr 4 19:47:42 2013
@@ -34,16 +34,16 @@
ULONG NextEaBufferOffset;
UINT IntEaLength;
- /* Length of the rest. Inital equal to EaLength */
+ /* Length of the rest. Initialize it to EaLength */
IntEaLength = EaLength;
- /* Inital EaBuffer equal to EaBuffer */
+ /* Initialize EaBuffer to EaBuffer */
EaBufferEnd = EaBuffer;
/* The rest length of the buffer */
/* 8 = sizeof(ULONG) + sizeof(UCHAR) + sizeof(UCHAR) + sizeof(USHORT) */
while (IntEaLength >= 8)
{
- /* rest of buffer must greater then the sizeof(FILE_FULL_EA_INFORMATION) + buffer */
+ /* The rest of the buffer must be greater than sizeof(FILE_FULL_EA_INFORMATION) + buffer */
NextEaBufferOffset = EaBufferEnd->EaNameLength+EaBufferEnd->EaValueLength + 9;
if (IntEaLength >= NextEaBufferOffset)
{
@@ -63,14 +63,14 @@
else
{
/*
- From the MSDN (http://msdn2.microsoft.com/en-us/library/ms795740.aspx).
+ From MSDN (http://msdn2.microsoft.com/en-us/library/ms795740.aspx).
For all entries except the last, the value of NextEntryOffset must be greater
than zero and must fall on a ULONG boundary.
*/
NextEaBufferOffset = ((NextEaBufferOffset + 3) & 0xFFFFFFFC);
if ((EaBufferEnd->NextEntryOffset == NextEaBufferOffset) && (EaBufferEnd->NextEntryOffset>0))
{
- /* rest of buffer must be greater then the next offset */
+ /* The rest of the buffer must be greater than the next offset */
IntEaLength = IntEaLength - EaBufferEnd->NextEntryOffset;
if (IntEaLength>=0)
{
@@ -86,7 +86,7 @@
if (ErrorOffset != NULL)
{
- /* calculate the error offset. Or in */
+ /* calculate the error offset. */
*ErrorOffset = (ULONG)((ULONG_PTR)EaBufferEnd - (ULONG_PTR)EaBuffer);
}
--- trunk/reactos/base/shell/cmd/del.c [iso-8859-1] (original)
+++ trunk/reactos/base/shell/cmd/del.c [iso-8859-1] Thu Apr 4 20:26:36 2013
@@ -107,7 +107,7 @@
{
/*setting file to normal, not saving old attrs first
because the file is going to be deleted anyways
- so the only thing that matters is that it isnt
+ so the only thing that matters is that it isn't
read only.*/
SetFileAttributes(lpFileName,FILE_ATTRIBUTE_NORMAL);
}
@@ -513,7 +513,7 @@
for (i = 0; i < args && !(dwFiles & 0x80000000); i++)
{
/*this checks to see if it isnt a flag, if it isnt, we assume it is a file name*/
if((*arg[i] == _T('/')) || (*arg[i] == _T('-')))
continue;
Modified: trunk/reactos/base/shell/cmd/readme2.txt
@@ -513,7 +513,7 @@
for (i = 0; i < args && !(dwFiles & 0x80000000); i++)
{
- /*this checks to see if it isnt a flag, if it isnt, we assume it is a file name*/
+ /*this checks to see if it is a flag; if it isn't, we assume it is a file name*/
if((*arg[i] == _T('/')) || (*arg[i] == _T('-')))
continue;
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/shell/cmd/readme2.txt…
==============================================================================